@@ -21,6 +21,7 @@
 
 package HTML::TableParser;
 
+require 5.8.1;
 use strict;
 use warnings;
 
@@ -34,7 +35,7 @@ use HTML::TableParser::Table;
 
 our @ISA = qw(HTML::Parser);
 
-our $VERSION = '0.37.1';
+our $VERSION = '0.38_01';
 
 # Preloaded methods go here.
 
